@@ -4,7 +4,7 @@ package urpm::download;
 
 use strict;
 use urpm::msg;
-use urpm::util qw(cat_ basename dirname file_size max member output_safe reduce_pathname);
+use urpm::util;
 use bytes ();
 use Cwd;
 use Exporter;
@@ -926,7 +926,6 @@ sub sync_rel {
 	$urpm->{log}(N("retrieved %s", $files_text));
 	\@result_files;
     } else {
-	$urpm->{log}("error: $err");
 	# don't leave partial download
 	unlink @result_files;
 	undef;
