@@ -1,7 +1,7 @@
 package urpm::orphans;
 
 use strict;
-use urpm::util qw(add2hash_ append_to_file cat_ output_safe partition put_in_hash uniq wc_l);
+use urpm::util;
 use urpm::msg;
 use urpm;
 
@@ -61,7 +61,7 @@ sub unrequested_list {
 
 =item mark_as_requested($urpm, $state, $test)
 
-Mark some packages as explicitly requested (usually because
+Mark some packages as explicitely requested (usually because
 they were manually installed).
 
 =cut
@@ -442,11 +442,7 @@ sub _all_unrequested_orphans {
 
     # do not offer to remove current kernel or DKMS modules for current kernel:
     delete $l{$current_kernel};
-    # prevent removing orphan kernels if we failed to detect running kernel version:
-    if ($current_kernel_version) {
-        do { delete $l{$_} } foreach grep { /$current_kernel_version/ } keys %l;
-    }
-
+    do { delete $l{$_} } foreach grep { /$current_kernel_version/ } keys %l;
     [ values %l ];
 }
 
@@ -599,6 +595,6 @@ sub installed_leaves {
 
 Copyright (C) 2008-2010 Mandriva SA
 
-Copyright (C) 2011-2013 Mageia
+Copyright (C) 2011-2012 Mageia
 
 =cut
